/*
 * Copyright 2019-2020 by Kappich Systemberatung, Aachen
 *
 * This file is part of de.bsvrz.ars.ars.
 *
 * de.bsvrz.ars.ars is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * de.bsvrz.ars.ars is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with de.bsvrz.ars.ars.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Contact Information:
 * Kappich Systemberatung
 * Martin-Luther-Straße 14
 * 52062 Aachen, Germany
 * phone: +49 241 4090 436
 * mail: <info@kappich.de>
 */

package de.bsvrz.ars.ars.persistence;

/**
 * Interface für Daten eines offenen Containers. Diese werden aus Performancegründen hier statt im Index gespeichert.
 *
 * @author Kappich Systemberatung
 */
public interface OpenContainerData {
	
	/** 
	 * Gibt die Anzahl Datensätze im Container zurück. Dieser Wert ist immer &gt; 0
	 * @return die Anzahl Datensätze im Container
	 */
	long getNumContainerEntries();

	/** 
	 * Gibt die minimale Archivzeit zurück
	 * @return die minimale Archivzeit
	 */
	long getMinArcTime();

	/** 
	 * Gibt die maximale Archivzeit zurück
	 * @return die maximale Archivzeit
	 */
	long getMaxArcTime();

	/** 
	 * Gibt die minimale Datenzeit zurück
	 * @return die minimale Datenzeit
	 */
	long getMinDataTime();

	/** 
	 * Gibt die maximale Datenzeit zurück
	 * @return die maximale Datenzeit
	 */
	long getMaxDataTime();

	/** 
	 * Gibt den minimalen Datenindex zurück
	 * @return den minimalen Datenindex
	 */
	long getMinDataIdx();

	/** 
	 * Gibt den maximalen Datenindex zurück
	 * @return den maximalen Datenindex
	 */
	long getMaxDataIdx();

	/** 
	 * Gibt die ID des offenen Containers zurück
	 * @return die ID des offenen Containers
	 */
	long getContainerId();
}
