/*
 *
 * Copyright 2005-2008 by beck et al. projects GmbH, Munich
 * Copyright 2009-2019 by Kappich Systemberatung, Aachen
 *
 * This file is part of de.bsvrz.ars.ars.
 *
 * de.bsvrz.ars.ars is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * de.bsvrz.ars.ars is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with de.bsvrz.ars.ars.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Contact Information:
 * Kappich Systemberatung
 * Martin-Luther-Straße 14
 * 52062 Aachen, Germany
 * phone: +49 241 4090 436
 * mail: <info@kappich.de>
 */

package de.bsvrz.ars.ars.persistence.index;

import java.io.File;
import java.nio.file.Path;

/**
 * Allgemeine Exception für Index Fehler. Alle anderen Exceptions leiten sich von dieser Klasse ab.
 *
 * @author beck et al. projects GmbH
 * @author Phil Schrettenbrunner
 * @version $Revision$ / $Date$ / ($Author$)
 */
public class IndexException extends Exception {

	/**
	 *
	 */
	private static final long serialVersionUID = 1L;

	/**
	 * IndexException mit Fehlermeldung
	 *
	 * @param msg Fehlermeldung
	 * @param file Datei
	 */
	public IndexException(String msg, final File file) {
		super(msg + ". Datei: " + file.getAbsolutePath());
	}
	
	/**
	 * IndexException mit Fehlermeldung
	 *
	 * @param msg Fehlermeldung
	 * @param file Datei
	 */
	public IndexException(String msg, final Path file) {
		super(msg + ". Datei: " + file.toAbsolutePath());
	}

	/**
	 * Erzeugt einen neue Instanz
	 * @param message Nachricht
	 * @param file Datei
	 * @param cause Ursache
	 */
	public IndexException(final String message, final File file, final Throwable cause) {
		super(message + ". Datei: " + file.getAbsolutePath(), cause);
	}
	
	/**
	 * Erzeugt einen neue Instanz
	 * @param message Nachricht
	 * @param file Datei
	 * @param cause Ursache
	 */
	public IndexException(final String message, final Path file, final Throwable cause) {
		super(message + ". Datei: " + file.toAbsolutePath(), cause);
	}
}
