/*
 *
 * Copyright 2017-2020 by Kappich Systemberatung, Aachen
 *
 * This file is part of de.bsvrz.ars.ars.
 *
 * de.bsvrz.ars.ars is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * de.bsvrz.ars.ars is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with de.bsvrz.ars.ars.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Contact Information:
 * Kappich Systemberatung
 * Martin-Luther-Straße 14
 * 52062 Aachen, Germany
 * phone: +49 241 4090 436
 * mail: <info@kappich.de>
 */

package de.bsvrz.ars.ars.persistence.walk;

import de.bsvrz.ars.ars.mgmt.datatree.synchronization.SyncKey;
import de.bsvrz.ars.ars.mgmt.tasks.AbstractTask;
import de.bsvrz.ars.ars.persistence.ContainerHeaders;
import de.bsvrz.ars.ars.persistence.DataIdentificationDir;
import de.bsvrz.ars.ars.persistence.IdDataIdentification;
import de.bsvrz.dav.daf.main.archive.ArchiveDataKind;
import java.util.Collection;

/**
 * Eine Aktion, die auf einen Container angewendet werden kann
 *
 * @author Kappich Systemberatung
 */
@FunctionalInterface
public interface ContainerAction {

	/**
	 * Führt die Aktion aus.
	 *
	 * @param dataIdentificationDir Verzeichnis des Containers
	 * @param lock                  Synchronisierungs-Schlüssel
	 * @param archiveDataKind       Archivdatenart
	 * @param headers          Liste mit Containern dieser DataIdentNode
	 * @throws Exception Beliebige Exception (führt zum Abbruch der Operation)
	 */
	void run(DataIdentificationDir dataIdentificationDir, SyncKey<IdDataIdentification> lock, ArchiveDataKind archiveDataKind, Collection<ContainerHeaders> headers) throws Exception;

	/**
	 * Wird (unsynchronisiert) vor dem Betreten eines Verzeichnisses ausgeführt. Hier wäre der richtige Paltz um Abbruchbedingungen zu prüfen oder {@link AbstractTask#suspendTaskIfNecessary()} auszuführen.
	 * @param dataIdentificationDir
	 */
	default void preVisitDirectory(DataIdentificationDir dataIdentificationDir){}
}
